@@ -54,13 +54,22 @@ ViewContainerTabBar::ViewContainerTabBar(QWidget* parent, TabbedViewContainer* c
     setAcceptDrops(true);
     setMouseTracking(true);
 
+    _mousePressTimer = new QElapsedTimer();
+
     setWhatsThis(xi18nc("@info:whatsthis",
                        "<title>Tab Bar</title>"
                        "<para>The tab bar allows you to switch and move tabs. You can double-click a tab to change its name.</para>"));
 }
 
+ViewContainerTabBar::~ViewContainerTabBar()
+{
+    delete _mousePressTimer;
+}
+
 void ViewContainerTabBar::mousePressEvent(QMouseEvent* event)
 {
+    _mousePressTimer->start();
+
     if (event->buttons() == Qt::LeftButton) {
         _dragStart = event->pos();
     }
@@ -71,7 +80,8 @@ void ViewContainerTabBar::mouseMoveEvent(QMouseEvent* event)
 {
     if (event->buttons() == Qt::LeftButton) {
         QPoint dragPos = _dragStart - event->pos();
-        if (dragPos.manhattanLength() > QApplication::startDragDistance()) {
+        if (dragPos.manhattanLength() > QApplication::startDragDistance()
+            && _mousePressTimer->elapsed() > QApplication::startDragTime()) {
             int tab = tabAt(_dragStart);
             if (tab != -1) {
                 emit initiateDrag(tab);
